<?xml version="1.0" encoding="UTF-8"?>
<!-- Use subject to the conditions in the included file: LICENSE.bsd -->
<!-- $Id$ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                version="1.0">
  
  <xsl:template match="sidebar/title" mode="sidebar.title.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:inline xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:inline>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="author | copyright | legalnotice" mode="titlepage.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]">
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the element is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>  
  </xsl:template>
  
  <xsl:template match="year" mode="titlepage.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]">
        <xsl:variable name="class" select="generate-id()"/>
        <fo:inline xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the element is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:inline>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>  
  </xsl:template>
  
  <xsl:template match="title | subtitle" mode="book.titlepage.recto.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle | legalnotice" mode="book.titlepage.verso.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="subtitle" mode="book.verso.subtitle.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:inline xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:inline>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle" mode="part.titlepage.recto.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle | legalnotice" mode="part.titlepage.verso.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle" mode="appendix.titlepage.recto.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle | legalnotice" mode="appendix.titlepage.verso.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle" mode="bibliodiv.titlepage.recto.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle" mode="bibliodiv.titlepage.verso.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle" mode="chapter.titlepage.recto.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle | legalnotice" mode="chapter.titlepage.verso.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle" mode="bibliography.titlepage.recto.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle | legalnotice" mode="bibliography.titlepage.verso.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle" mode="section.titlepage.recto.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle | legalnotice" mode="section.titlepage.verso.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle" mode="sect1.titlepage.recto.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle | legalnotice" mode="sect1.titlepage.verso.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle" mode="sect2.titlepage.recto.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle | legalnotice" mode="sect2.titlepage.verso.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle" mode="sect3.titlepage.recto.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle | legalnotice" mode="sect3.titlepage.verso.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle" mode="sect4.titlepage.recto.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle | legalnotice" mode="sect4.titlepage.verso.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle" mode="sect5.titlepage.recto.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="title | subtitle | legalnotice" mode="sect5.titlepage.verso.auto.mode">
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <xsl:variable name="class" select="generate-id()"/>
        <fo:block xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="preface|chapter|appendix|bibliography|title|titleabbrev" mode="title.markup">
    <xsl:variable name="class" select="generate-id()"/>
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <fo:inline xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:inline>
      </xsl:when>
      <xsl:when test="child::title[@revisionflag='added']">
        <fo:inline xsl:use-attribute-sets='added.atts'>
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:inline>
      </xsl:when>
      <xsl:when test="child::title[@revisionflag='deleted']">
        <fo:inline xsl:use-attribute-sets='deleted.atts'>
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:inline>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="book|preface|chapter|appendix" mode="titleabbrev.markup">
    <xsl:variable name="class" select="generate-id()"/>
    <xsl:choose>
      <xsl:when test="ancestor-or-self::*[@revisionflag]"> 
        <fo:inline xsl:use-attribute-sets="ancestor.revision.atts">
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:inline>
      </xsl:when>
      <xsl:when test="child::title[@revisionflag='added']">
        <fo:inline xsl:use-attribute-sets='added.atts'>
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:inline>
      </xsl:when>
      <xsl:when test="child::title[@revisionflag='deleted']">
        <fo:inline xsl:use-attribute-sets='deleted.atts'>
          <!-- open a changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-begin change-bar-class="{$class}" xsl:use-attribute-sets="changebar.atts"/>
          </xsl:if>
          <xsl:apply-imports/>
          <!-- close the changebar here if the revisionflag is here and we have set them to be on -->
          <xsl:if test="$use.changebars != 0 ">
            <fo:change-bar-end change-bar-class="{$class}"/>
          </xsl:if>
        </fo:inline>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-imports/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
</xsl:stylesheet>